==> dokuwiki-2018.04.22ap2.tgz: dokuwiki/lib/plugins/extension/lang/pl/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Wojciech Lichota <wojciech@lichota.pl>
 * @author Max <maxrb146@gmail.com>
 * @author Mati <mackosa@wp.pl>
 */
$lang['menu']                  = 'Menedżer rozszerzeń';
$lang['tab_plugins']           = 'Zainstalowane dodatki';
$lang['tab_templates']         = 'Zainstalowane Szablony';
$lang['tab_search']            = 'Znajdź i zainstaluj';
$lang['tab_install']           = 'Instalacja ręczna';
$lang['notimplemented']        = 'Ta funkcja nie została jeszcze zaimplementowana';
$lang['notinstalled']          = 'Te rozszerzenie nie zostało zainstalowane';
$lang['alreadyenabled']        = 'Te rozszerzenie jest już uruchomione';
$lang['alreadydisabled']       = 'Rozszerzenie zostało wyłączone';
$lang['pluginlistsaveerror']   = 'Wystąpił błąd podczas zapisywania listy wtyczek';
$lang['unknownauthor']         = 'Nieznany autor';
$lang['unknownversion']        = 'Nieznana wersja';
$lang['btn_info']              = 'Pokaż więcej informacji';
$lang['btn_update']            = 'Aktualizuj';
$lang['btn_uninstall']         = 'Odinstaluj';
$lang['btn_enable']            = 'Uruchom';
$lang['btn_disable']           = 'Wyłącz';
$lang['btn_install']           = 'Instaluj';
$lang['btn_reinstall']         = 'Ponowna instalacja';
$lang['js']['reallydel']       = 'Naprawdę odinstalować te rozszerzenie?';
$lang['js']['display_viewoptions'] = 'Zobacz Opcje';
$lang['js']['display_enabled'] = 'włącz';
$lang['js']['display_disabled'] = 'wyłącz';
$lang['js']['display_updatable'] = 'do aktualizacji';
$lang['search_for']            = 'Szukaj rozszerzenia:';
$lang['search']                = 'Szukaj';
$lang['extensionby']           = '<strong>%s</strong> przez %s';
$lang['screenshot']            = 'Zrzut ekranu z %s';
$lang['popularity']            = 'Popularność: %s%%';
$lang['homepage_link']         = 'Dokumenty';
$lang['bugs_features']         = 'Błędy';
$lang['tags']                  = 'Tagi:';
$lang['author_hint']           = 'Szukaj rozszerzenia po autorze';
$lang['installed']             = 'Zainstalowano:';
$lang['downloadurl']           = 'Pobierz URL';
$lang['repository']            = 'Repozytorium';
$lang['unknown']               = '<em>nie znany</em>';
$lang['installed_version']     = 'Zainstalowana wersja:';
$lang['install_date']          = 'Twoja ostatnia aktualizacja:';
$lang['available_version']     = 'Dostępna wersja:';
$lang['compatible']            = 'Zgodny z:';
$lang['depends']               = 'Zależy od:';
$lang['similar']               = 'Podobny do:';
$lang['conflicts']             = 'Konflikt z:';
$lang['donate']                = 'Lubisz to?';
$lang['donate_action']         = 'Kup autorowi kawę!';
$lang['repo_retry']            = 'Ponów';
$lang['provides']              = 'Dostawcy:';
$lang['status']                = 'Status:';
$lang['status_installed']      = 'zainstalowano';
$lang['status_not_installed']  = 'nie zainstalowano';
$lang['status_protected']      = 'chroniony';
$lang['status_enabled']        = 'uruchomione';
$lang['status_disabled']       = 'wyłączone';
$lang['status_unmodifiable']   = 'niemodyfikowalny';
$lang['status_plugin']         = 'dodatek';
$lang['status_template']       = 'szablon';
$lang['status_bundled']        = 'paczka';
$lang['msg_enabled']           = 'Dodatek %s włączony';
$lang['msg_disabled']          = 'Dodatek %s wyłączony';
$lang['msg_delete_success']    = 'Rozszerzenie %s odinstalowane';
$lang['msg_delete_failed']     = 'Odinstalowywanie rozszerzenia %s nie powiodło się';
$lang['msg_template_install_success'] = 'Szablon %s został zainstalowany';
$lang['msg_template_update_success'] = 'Szablon %s został zaktualizowany';
$lang['msg_plugin_install_success'] = 'Dodatek %s został zainstalowany';
$lang['msg_plugin_update_success'] = 'Dodatek %s został zaktualizowany';
$lang['msg_upload_failed']     = 'Ładowanie pliku nie powiodło się';
$lang['missing_dependency']    = '<strong>Brakująca lub wyłączona zależność:</strong> %s';
$lang['security_issue']        = '<strong>Problemy bezpieczeństwa:</strong> %s';
$lang['security_warning']      = '<strong>Alert Bezpieczeństwa:</strong>%s';
$lang['update_available']      = '<strong>Uaktualnij</strong> Nowa wersja %s jest dostępna.';
$lang['wrong_folder']          = '<strong>Nieprawidłowo zainstalowana wtyczka:</strong> Zmień nazwę katalogu wtyczek z "%s" na "%s".';
$lang['url_change']            = '<strong>URL został zmieniony:</strong>URL zmienił się od czasu ostatniego pobrania. Przed aktualizacją rozszerzenia, sprawdź czy nowy adres URL jest prawidłowy.<br />Nowy: %s<br />Stary: %s';
$lang['error_badurl']          = 'URL powinien zaczynać się od http lub https';
$lang['error_dircreate']       = 'Nie można utworzyć tymczasowego folderu pobierania ';
$lang['error_download']        = 'Nie można pobrać pliku %s';
$lang['error_decompress']      = 'Nie można rozpakować pobranego pliku. Może to być spowodowane złym pobieraniem, w takim przypadku powinieneś spróbować ponownie; lub format kompresji może być nieznany, w takim przypadku należy ręcznie pobrać i zainstalować.';
$lang['error_findfolder']      = 'Nie można zidentyfikować katalogu z rozszerzeniami, musisz pobrać i zainstalować ręcznie';
$lang['error_copy']            = 'Wystąpił błąd kopiowania pliku podczas próby zainstalowania plików dla katalogu <em>%s</em>: dysk może być pełny lub uprawnienia dostępu do pliku mogą być niepoprawne. Mogło to spowodować częściowo zainstalowaną wtyczkę i pozostawić twoją instalację wiki niestabilną';
$lang['noperms']               = 'Katalog z rozszerzeniami nie posiada uprawnień zapisu';
$lang['notplperms']            = 'Katalog z szablonami nie posiada uprawnień zapisu';
$lang['nopluginperms']         = 'Katalog z wtyczkami nie posiada uprawnień zapisu';
$lang['git']                   = 'To rozszerzenie zostało zainstalowane przez git, możesz nie chcieć go aktualizować tutaj.';
$lang['auth']                  = 'Ta wtyczka autoryzacji nie jest włączona w konfiguracji, rozważ jej wyłączenie.';
$lang['install_url']           = 'Instaluj z URL:';
$lang['install_upload']        = 'Załaduj Rozszerzenie ';
$lang['repo_error']            = 'Nie można skontaktować się z repozytorium wtyczek. Upewnij się, że twój serwer może skontaktować się z www.dokuwiki.org i sprawdzić ustawienia serwera proxy.';
$lang['nossl']                 = 'Twój PHP wydaje się nie obsługiwać protokołu SSL. Pobieranie nie zadziała dla wielu rozszerzeń DokuWiki.';

==> dokuwiki-2024.02.06p0.tgz: dokuwiki/lib/plugins/extension/lang/pl/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Marek Adamski <fevbew@wp.pl>
 * @author pavulondit <pavloo@vp.pl>
 * @author Wojciech Lichota <wojciech@lichota.pl>
 * @author Max <maxrb146@gmail.com>
 * @author Mati <mackosa@wp.pl>
 */
$lang['menu']                  = 'Menedżer rozszerzeń';
$lang['tab_plugins']           = 'Zainstalowane dodatki';
$lang['tab_templates']         = 'Zainstalowane Szablony';
$lang['tab_search']            = 'Znajdź i zainstaluj';
$lang['tab_install']           = 'Instalacja ręczna';
$lang['notimplemented']        = 'Ta funkcja nie została jeszcze zaimplementowana';
$lang['notinstalled']          = 'Te rozszerzenie nie zostało zainstalowane';
$lang['alreadyenabled']        = 'Te rozszerzenie jest już uruchomione';
$lang['alreadydisabled']       = 'Rozszerzenie zostało wyłączone';
$lang['pluginlistsaveerror']   = 'Wystąpił błąd podczas zapisywania listy wtyczek';
$lang['unknownauthor']         = 'Nieznany autor';
$lang['unknownversion']        = 'Nieznana wersja';
$lang['btn_info']              = 'Pokaż więcej informacji';
$lang['btn_update']            = 'Aktualizuj';
$lang['btn_uninstall']         = 'Odinstaluj';
$lang['btn_enable']            = 'Uruchom';
$lang['btn_disable']           = 'Wyłącz';
$lang['btn_install']           = 'Instaluj';
$lang['btn_reinstall']         = 'Ponowna instalacja';
$lang['js']['reallydel']       = 'Naprawdę odinstalować te rozszerzenie?';
$lang['js']['display_viewoptions'] = 'Zobacz Opcje';
$lang['js']['display_enabled'] = 'włącz';
$lang['js']['display_disabled'] = 'wyłącz';
$lang['js']['display_updatable'] = 'do aktualizacji';
$lang['search_for']            = 'Szukaj rozszerzenia:';
$lang['search']                = 'Szukaj';
$lang['extensionby']           = '<strong>%s</strong> przez %s';
$lang['screenshot']            = 'Zrzut ekranu z %s';
$lang['popularity']            = 'Popularność: %s%%';
$lang['homepage_link']         = 'Dokumenty';
$lang['bugs_features']         = 'Błędy';
$lang['tags']                  = 'Tagi:';
$lang['author_hint']           = 'Szukaj rozszerzenia po autorze';
$lang['installed']             = 'Zainstalowano:';
$lang['downloadurl']           = 'Pobierz URL';
$lang['repository']            = 'Repozytorium';
$lang['unknown']               = '<em>nie znany</em>';
$lang['installed_version']     = 'Zainstalowana wersja:';
$lang['install_date']          = 'Twoja ostatnia aktualizacja:';
$lang['available_version']     = 'Dostępna wersja:';
$lang['compatible']            = 'Zgodny z:';
$lang['depends']               = 'Zależy od:';
$lang['similar']               = 'Podobny do:';
$lang['conflicts']             = 'Konflikt z:';
$lang['donate']                = 'Lubisz to?';
$lang['donate_action']         = 'Kup autorowi kawę!';
$lang['repo_retry']            = 'Ponów';
$lang['provides']              = 'Dostawcy:';
$lang['status']                = 'Status:';
$lang['status_installed']      = 'zainstalowano';
$lang['status_not_installed']  = 'nie zainstalowano';
$lang['status_protected']      = 'chroniony';
$lang['status_enabled']        = 'uruchomione';
$lang['status_disabled']       = 'wyłączone';
$lang['status_unmodifiable']   = 'niemodyfikowalny';
$lang['status_plugin']         = 'dodatek';
$lang['status_template']       = 'szablon';
$lang['status_bundled']        = 'paczka';
$lang['msg_enabled']           = 'Dodatek %s włączony';
$lang['msg_disabled']          = 'Dodatek %s wyłączony';
$lang['msg_delete_success']    = 'Rozszerzenie %s odinstalowane';
$lang['msg_delete_failed']     = 'Odinstalowywanie rozszerzenia %s nie powiodło się';
$lang['msg_template_install_success'] = 'Szablon %s został zainstalowany';
$lang['msg_template_update_success'] = 'Szablon %s został zaktualizowany';
$lang['msg_plugin_install_success'] = 'Dodatek %s został zainstalowany';
$lang['msg_plugin_update_success'] = 'Dodatek %s został zaktualizowany';
$lang['msg_upload_failed']     = 'Ładowanie pliku nie powiodło się';
$lang['msg_nooverwrite']       = 'Rozszerzenie %s już istnieje więc nie zostanie nadpisane; aby nadpisać zaznacz opcję nadpisz.';
$lang['missing_dependency']    = '<strong>Brakująca lub wyłączona zależność:</strong> %s';
$lang['security_issue']        = '<strong>Problemy bezpieczeństwa:</strong> %s';
$lang['security_warning']      = '<strong>Alert Bezpieczeństwa:</strong>%s';
$lang['update_message']        = '<strong>Wiadomość o aktualizacji:</strong> %s';
$lang['update_available']      = '<strong>Uaktualnij</strong> Nowa wersja %s jest dostępna.';
$lang['wrong_folder']          = '<strong>Nieprawidłowo zainstalowana wtyczka:</strong> Zmień nazwę katalogu wtyczek z "%s" na "%s".';
$lang['url_change']            = '<strong>URL został zmieniony:</strong>URL zmienił się od czasu ostatniego pobrania. Przed aktualizacją rozszerzenia, sprawdź czy nowy adres URL jest prawidłowy.<br />Nowy: %s<br />Stary: %s';
$lang['error_badurl']          = 'URL powinien zaczynać się od http lub https';
$lang['error_dircreate']       = 'Nie można utworzyć tymczasowego folderu pobierania ';
$lang['error_download']        = 'Nie można pobrać pliku %s';
$lang['error_decompress']      = 'Nie można rozpakować pobranego pliku. Może to być spowodowane złym pobieraniem, w takim przypadku powinieneś spróbować ponownie; lub format kompresji może być nieznany, w takim przypadku należy ręcznie pobrać i zainstalować.';
$lang['error_findfolder']      = 'Nie można zidentyfikować katalogu z rozszerzeniami, musisz pobrać i zainstalować ręcznie';
$lang['error_copy']            = 'Wystąpił błąd kopiowania pliku podczas próby zainstalowania plików dla katalogu <em>%s</em>: dysk może być pełny lub uprawnienia dostępu do pliku mogą być niepoprawne. Mogło to spowodować częściowo zainstalowaną wtyczkę i pozostawić twoją instalację wiki niestabilną';
$lang['noperms']               = 'Katalog z rozszerzeniami nie posiada uprawnień zapisu';
$lang['notplperms']            = 'Katalog z szablonami nie posiada uprawnień zapisu';
$lang['nopluginperms']         = 'Katalog z wtyczkami nie posiada uprawnień zapisu';
$lang['git']                   = 'To rozszerzenie zostało zainstalowane przez git, możesz nie chcieć go aktualizować tutaj.';
$lang['auth']                  = 'Ta wtyczka autoryzacji nie jest włączona w konfiguracji, rozważ jej wyłączenie.';
$lang['install_url']           = 'Instaluj z URL:';
$lang['install_upload']        = 'Załaduj Rozszerzenie ';
$lang['repo_badresponse']      = 'Repozytorium wtyczek zwróciło nieprawidłową odpowiedź.';
$lang['repo_error']            = 'Nie można skontaktować się z repozytorium wtyczek. Upewnij się, że twój serwer może skontaktować się z www.dokuwiki.org i sprawdzić ustawienia serwera proxy.';
$lang['nossl']                 = 'Twój PHP wydaje się nie obsługiwać protokołu SSL. Pobieranie nie zadziała dla wielu rozszerzeń DokuWiki.';
